pub struct SocketProbeSpec {
pub host: String,
pub port: Option<u16>,
pub payload: Option<Vec<u8>>,
pub tls: bool,
pub session: bool,
pub read_max: u32,
pub read_idle_ms: u32,
}Expand description
Generic socket options (shared by dns/tcp/udp probes).
Fields
host: Stringport: Option<u16>payload: Option<Vec<u8>>tls: boolTLS handshake before application data (TCP only).
session: boolKeep connection open across multiple send on the same probe name.
read_max: u32Maximum bytes to read per exchange (default 65536).
read_idle_ms: u32After first read, keep reading until idle for this many ms (0 = single read).
Implementations
Sourceimpl SocketProbeSpec
impl SocketProbeSpec
pub fn is_dns_resolver_mode(&self) -> bool